Package: xgboost
Type: Package
Title: Extreme Gradient Boosting
Version: 1.7.3.1
Date: 2023-01-06
Authors@R: c(
  person("Tianqi", "Chen", role = c("aut"),
         email = "tianqi.tchen@gmail.com"),
  person("Tong", "He", role = c("aut"),
         email = "hetong007@gmail.com"),
  person("Michael", "Benesty", role = c("aut"),
         email = "michael@benesty.fr"),
  person("Vadim", "Khotilovich", role = c("aut"),
         email = "khotilovich@gmail.com"),
  person("Yuan", "Tang", role = c("aut"),
         email = "terrytangyuan@gmail.com",
         comment = c(ORCID = "0000-0001-5243-233X")),
  person("Hyunsu", "Cho", role = c("aut"),
         email = "chohyu01@cs.washington.edu"),
  person("Kailong", "Chen", role = c("aut")),
  person("Rory", "Mitchell", role = c("aut")),
  person("Ignacio", "Cano", role = c("aut")),
  person("Tianyi", "Zhou", role = c("aut")),
  person("Mu", "Li", role = c("aut")),
  person("Junyuan", "Xie", role = c("aut")),
  person("Min", "Lin", role = c("aut")),
  person("Yifeng", "Geng", role = c("aut")),
  person("Yutian", "Li", role = c("aut")),
  person("Jiaming", "Yuan", role = c("aut", "cre"),
         email = "jm.yuan@outlook.com"),
  person("XGBoost contributors", role = c("cph"),
         comment = "base XGBoost implementation")
  )
Maintainer: Jiaming Yuan <jm.yuan@outlook.com>
Description: Extreme Gradient Boosting, which is an efficient implementation
    of the gradient boosting framework from Chen & Guestrin (2016) <doi:10.1145/2939672.2939785>.
    This package is its R interface. The package includes efficient linear
    model solver and tree learning algorithms. The package can automatically
    do parallel computation on a single machine which could be more than 10
    times faster than existing gradient boosting packages. It supports
    various objective functions, including regression, classification and ranking.
    The package is made to be extensible, so that users are also allowed to define
    their own objectives easily.
License: Apache License (== 2.0) | file LICENSE
URL: https://github.com/dmlc/xgboost
BugReports: https://github.com/dmlc/xgboost/issues
NeedsCompilation: yes
VignetteBuilder: knitr
Suggests: knitr, rmarkdown, ggplot2 (>= 1.0.1), DiagrammeR (>= 0.9.0),
        Ckmeans.1d.dp (>= 3.3.1), vcd (>= 1.3), testthat, lintr, igraph
        (>= 1.0.1), float, crayon, titanic
Depends: R (>= 3.3.0)
Imports: Matrix (>= 1.1-0), methods, data.table (>= 1.9.6), jsonlite
        (>= 1.0),
RoxygenNote: 7.2.2
SystemRequirements: GNU make, C++14
Author: Tianqi Chen [aut],
  Tong He [aut],
  Michael Benesty [aut],
  Vadim Khotilovich [aut],
  Yuan Tang [aut] (<https://orcid.org/0000-0001-5243-233X>),
  Hyunsu Cho [aut],
  Kailong Chen [aut],
  Rory Mitchell [aut],
  Ignacio Cano [aut],
  Tianyi Zhou [aut],
  Mu Li [aut],
  Junyuan Xie [aut],
  Min Lin [aut],
  Yifeng Geng [aut],
  Yutian Li [aut],
  Jiaming Yuan [aut, cre],
  XGBoost contributors [cph] (base XGBoost implementation)
Built: R 3.5.1; x86_64-conda_cos6-linux-gnu; 2023-02-03 21:01:17 UTC; unix
